@@ -773,6 +773,19 @@ class KeycloakAdmin:
         data_raw = self.connection.raw_delete(URL_ADMIN_CLIENT_AUTHZ_RESOURCES_ID.format(**params_path))
         return raise_error_from_response(data_raw, KeycloakGetError, expected_code=204)
 
+    def get_client_authz_policy(self, client_id, query, policy_type='role'):
+        """
+        Get policies from client.
+
+        :param client_id: id in ClientRepresentation
+        http://www.keycloak.org/docs-api/3.3/rest-api/index.html#_clientrepresentation
+        :return: Keycloak server response
+        """
+
+        params_path = {"realm-name": self.realm_name, "id": client_id, "policy-type": policy_type}
+        data_raw = self.connection.raw_get(URL_ADMIN_CLIENT_AUTHZ_POLICIES.format(**params_path), **query)
+        return raise_error_from_response(data_raw, KeycloakGetError)
+
     def create_client_authz_policy(self, client_id, payload, policy_type='role', skip_exists=False):
         """
         Create a policy.
